Modules
- aeon
- “Standard” algorithms mostly adapted from Aeon.
- control
- experiment_
utils - Utility module with helper methods for running experiments based on the attached network_sampler.py and run_groups.py
- perturbation
- A perturbed version of the symbolic asynchronous graph. We keep it in a separate module because the implementation is very fragile and we want to hide as much of the API as possible even from ourselves!
- phenotype_
control - tests